@@ -164,12 +164,15 @@ def django_instance_field_to_redis_value(
     django_field_value = getattr(django_instance, django_field.name)
     redis_value = django_field_value
     if django_field.__class__ == django_models.ForeignKey:
-        django_foreign_key_instance = django_field_value
-        redis_value = get_or_create_redis_instance_from_django_instance(
-            django_foreign_key_instance,
-            redis_root,
-            get_or_create_redis_model_from_django_model
-        )
+        if django_field_value is None:
+            redis_value = -1
+        else:
+            django_foreign_key_instance = django_field_value
+            redis_value = get_or_create_redis_instance_from_django_instance(
+                django_foreign_key_instance,
+                redis_root,
+                get_or_create_redis_model_from_django_model
+            )
 
     elif django_field.__class__ == django_models.ManyToManyField:
         redis_value = [
@@ -212,20 +215,17 @@ def get_or_create_redis_instance_from_django_instance(
         get_or_create_redis_model_from_django_model
 ):
     django_instance_model = django_instance.__class__
-    print(django_instance, django_instance_model)
-    if django_instance_model:
-        redis_model = get_or_create_redis_model_from_django_model(django_instance_model, redis_root)
-        redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
-        if not redis_instance:
-            redis_dict = django_instance_to_redis_params(django_instance, redis_root, get_or_create_redis_model_from_django_model)
-            redis_model(
-                redis_root=redis_root,
-                django_id=django_instance.id,
-                **redis_dict
-            ).save()
-            redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
-        else:
-            redis_instance = redis_instance[0]
+    redis_model = get_or_create_redis_model_from_django_model(django_instance_model, redis_root)
+    redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
+    if not redis_instance:
+        redis_dict = django_instance_to_redis_params(django_instance, redis_root, get_or_create_redis_model_from_django_model)
+        redis_model(
+            redis_root=redis_root,
+            django_id=django_instance.id,
+            **redis_dict
+        ).save()
+        redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
     else:
-        redis_instance = None
+        redis_instance = redis_instance[0]
+
     return redis_instance
